summaryrefslogtreecommitdiff
path: root/gtk2_ardour/marker_time_axis.cc
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/marker_time_axis.cc')
-rw-r--r--gtk2_ardour/marker_time_axis.cc11
1 files changed, 5 insertions, 6 deletions
diff --git a/gtk2_ardour/marker_time_axis.cc b/gtk2_ardour/marker_time_axis.cc
index dd827b4c3c..4cc2cec92f 100644
--- a/gtk2_ardour/marker_time_axis.cc
+++ b/gtk2_ardour/marker_time_axis.cc
@@ -36,7 +36,6 @@
#include "marker_time_axis_view.h"
#include "imageframe_view.h"
#include "marker_time_axis.h"
-#include "canvas_impl.h"
#include "i18n.h"
@@ -121,18 +120,18 @@ MarkerTimeAxis::set_height (uint32_t h)
}
/**
* Sets the number of samples per unit that are used.
* This is used to determine the sizes of items upon this time axis
*
* @param spu the number of samples per unit
*/
void
-MarkerTimeAxis::set_samples_per_unit(double spu)
+MarkerTimeAxis::set_frames_per_pixel (double fpp)
{
- TimeAxisView::set_samples_per_unit (editor.get_current_zoom());
+ TimeAxisView::set_frames_per_pixel (editor.get_current_zoom());
if (view) {
- view->set_samples_per_unit(spu) ;
+ view->set_frames_per_pixel (fpp);
}
}
@@ -121,18 +120,18 @@ MarkerTimeAxis::set_height (uint32_t h)
}
/**
- * Sets the number of samples per unit that are used.
+ * Sets the number of frames per pixel that are used.
* This is used to determine the sizes of items upon this time axis
*
@@ -121,18 +120,18 @@ MarkerTimeAxis::set_height (uint32_t h)
* This is used to determine the sizes of items upon this time axis
*
- * @param spu the number of samples per unit
+ * @param spu the number of frames per pixel
*/
void